windows

package
v0.2.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 17, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CredName

func CredName(service, username string) string

CredName combines service and username to a single string target.

func MatchesPrefix

func MatchesPrefix(service, targetName string) bool

MatchesPrefix checks if targetName belongs to service.

func ValidateTargetAndBlob

func ValidateTargetAndBlob(service, password string) error

ValidateTargetAndBlob checks size limits according to Windows Credential Manager constraints.

Types

This section is empty.

Jump to